You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by mi...@apache.org on 2012/09/25 17:37:36 UTC

svn commit: r1389932 - /lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java

Author: mikemccand
Date: Tue Sep 25 15:37:36 2012
New Revision: 1389932

URL: http://svn.apache.org/viewvc?rev=1389932&view=rev
Log:
remove nocommits

Modified:
    lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java

Modified: lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java?rev=1389932&r1=1389931&r2=1389932&view=diff
==============================================================================
--- lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java (original)
+++ lucene/dev/branches/lucene3842/lucene/core/src/test/org/apache/lucene/index/BinaryTokenStream.java Tue Sep 25 15:37:36 2012
@@ -21,11 +21,14 @@ import org.apache.lucene.analysis.TokenS
 import org.apache.lucene.analysis.tokenattributes.TermToBytesRefAttribute;
 import org.apache.lucene.util.AttributeImpl;
 import org.apache.lucene.util.BytesRef;
+import org.apache.lucene.util.CannedBinaryTokenStream; // javadocs
 
 /**
  * a binary tokenstream that lets you index a BytesRef
  */
-// nocommit absorb into CannedBinaryTS?
 public final class BinaryTokenStream extends TokenStream {
   private final ByteTermAttribute bytesAtt = addAttribute(ByteTermAttribute.class);
   private boolean available = true;
@@ -62,10 +65,8 @@ public final class BinaryTokenStream ext
     public BytesRef getBytesRef() {
       return bytes;
     }
-    
+
     public void setBytesRef(BytesRef bytes) {
-      // nocommit isn't this dangerous?  the getBytesRef is
-      // pre-shared?  so you can't set this per token?
       this.bytes = bytes;
     }
@@ -21,11 +21,14 @@ import org.apache.lucene.analysis.TokenS
 
 /**
- * a binary tokenstream that lets you index a BytesRef
+ * A binary tokenstream that lets you index a single
+ * binary token (BytesRef value).
+ *
+ * @see CannedBinaryTokenStream
  */